%% LaTeX document class for typesetting of slides and accompanying notes
%%
%% Copyright (c) 2000 Marek Kisiel-Dorohinicki
%%
%% $Log: slideshow.cls,v $
%% Revision 0.4  2000-11-24 11:28:04+01  doroh
%% further changes to spacing params
%%
%% Revision 0.3  2000-11-22 21:02:34+01  doroh
%% modified spacing params (baseline, paragraph, display, list, etc.)
%% notitlepage as default
%%
%% Revision 0.2  2000-10-25 18:43:50+01  doroh
%% slide contents saved using 'saveminipage' environment
%%   (which allows for shrinking of long slides)
%% added \newpage to \end@slide
%%   (no underfull vbox warning when notes are present between slides)
%%
%% Revision 0.1  2000-10-22 20:24:31+01  doroh
%% font and paragraph settings based on standard LaTeX class 'slides'
%% slide organisation based on package 'slidenotes'
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}[1997/06/01]
\ProvidesClass{slideshow}

\RequirePackage{saveminipage}
\InputIfFileExists{sfonts.cfg}
  {\typeout{Local config file sfonts.cfg used}}%
  {\input{sfonts.def}}

\DeclareOption{a4paper}
   {\setlength\paperheight {297mm}%
    \setlength\paperwidth  {210mm}}
\DeclareOption{a5paper}
   {\setlength\paperheight {210mm}%
    \setlength\paperwidth  {148mm}}
\DeclareOption{b5paper}
   {\setlength\paperheight {250mm}%
    \setlength\paperwidth  {176mm}}
\DeclareOption{letterpaper}
   {\setlength\paperheight {11in}%
    \setlength\paperwidth  {8.5in}}
\DeclareOption{legalpaper}
   {\setlength\paperheight {14in}%
    \setlength\paperwidth  {8.5in}}
\DeclareOption{executivepaper}
   {\setlength\paperheight {10.5in}%
    \setlength\paperwidth  {7.25in}}
\DeclareOption{landscape}
   {\setlength\@tempdima   {\paperheight}%
    \setlength\paperheight {\paperwidth}%
    \setlength\paperwidth  {\@tempdima}%
    \special{landscape}}

%% \@twosidefalse
\DeclareOption{draft}{\setlength\overfullrule{5pt}}
\DeclareOption{final}{\setlength\overfullrule{0pt}}

\newif\if@titlepage
\DeclareOption{titlepage}{\@titlepagetrue}
\DeclareOption{notitlepage}{\@titlepagefalse}

\newif\if@titleslide
\DeclareOption{titleslide}{\@titleslidetrue}
\DeclareOption{notitleslide}{\@titleslidefalse}

\DeclareOption{onecolumn}{}
\DeclareOption{twocolumn}{%
    \ClassWarning{slides}{No 'twocolumn' layout for slideshow}}

\DeclareOption{leqno}{\input{leqno.clo}}
\DeclareOption{fleqn}{\input{fleqn.clo}}

\newif\if@slides
\newif\if@notes
\DeclareOption{slidenotes}{\@slidestrue\@notestrue}

\DeclareOption{stretch}{\def\slidealignment{s}}
\DeclareOption{flushtop}{\def\slidealignment{t}}
\DeclareOption{center}{\def\slidealignment{c}}
\DeclareOption{flushbottom}{\def\slidealignment{b}}
\newif\if@belowheadfil
\DeclareOption{spacious}{\@belowheadfiltrue}
\DeclareOption{tight}{\@belowheadfilfalse}

\newcommand{\framevariant}{}
\DeclareOption{noframe}{\renewcommand{\framevariant}{0}}
\DeclareOption{rules}{\renewcommand{\framevariant}{1}}
\DeclareOption{rect}{\renewcommand{\framevariant}{2}}
\DeclareOption{shadow}{\renewcommand{\framevariant}{3}}
\DeclareOption{double}{\renewcommand{\framevariant}{4}}
\DeclareOption{oval}{\renewcommand{\framevariant}{5}}

\ExecuteOptions{a4paper,final,slidenotes,center,tight,rules}
\ProcessOptions

\IfFileExists{frbox.sty}
  {\RequirePackage{frbox}}
  {\ifnum\framevariant>1
   \PackageWarningNoLine{slideshow}
     {rect, double, shadow & oval options disabled}%
   \renewcommand{\framevariant}{1}\fi}

\def\rmdefault{lcmss} %% no roman
\def\sfdefault{lcmss}
\def\ttdefault{lcmtt}
\def\itdefault{sl}
\def\sldefault{sl}
\def\bfdefault{bx}
\def\ifourteenpt{13.82}
\def\iseventeenpt{16.59}
\def\itwentypt{19.907}
\def\itwentyfourpt{23.89}
\def\itwentyninept{28.66}
\def\ithirtyfourpt{34.4}
\def\ifortyonept{41.28}
\def\@setfontsize@parms#1#2#3{%
  \lineskip 2\p@
  \parskip #1\relax
  \abovedisplayskip #1\relax
  \belowdisplayskip #1\relax
  \abovedisplayshortskip \z@ plus3\p@
  \belowdisplayshortskip #1\relax
  \divide\belowdisplayshortskip by\tw@
  \setbox\strutbox=\hbox{\vrule \@height#2\p@\@depth#3\p@\@width\z@}}
\DeclareMathSizes{13.82}{13.82}{10}{7}
\DeclareMathSizes{16.59}{16.59}{12}{7}
\DeclareMathSizes{19.907}{19.907}{16.59}{13.82}
\DeclareMathSizes{23.89}{23.89}{19.907}{16.59}
\DeclareMathSizes{28.66}{28.66}{23.89}{19.907}
\DeclareMathSizes{34.4}{34.4}{28.66}{23.89}
\DeclareMathSizes{41.28}{41.28}{34.4}{28.66}
\def\normalsize{%
      \@setfontsize\normalsize\itwentypt{28\p@ plus3\p@ minus3\p@}%
      \@setfontsize@parms{18\p@ plus9\p@ minus9\p@}{17}{7}}
\normalsize
\def\small{\@setfontsize\small\iseventeenpt{23\p@ plus2\p@ minus\p@}%
           \@setfontsize@parms{12\p@ plus6\p@ minus6\p@}{13.5}{5.6}}
\let\footnotesize=\small
\let\scriptsize=\small
\def\tiny{\@setfontsize\tiny\ifourteenpt{19\p@ plus2\p@ minus\p@}%
          \@setfontsize@parms{9\p@ plus6\p@ minus6\p@}{10}{4}}
\def\large{\@setfontsize\large\itwentyfourpt{32\p@ plus8\p@ minus5\p@}%
           \@setfontsize@parms{40\p@ plus20\p@ minus4\p@}{20}{8.5}}
\def\Large{\@setfontsize\Large\itwentyninept{40\p@ plus10\p@ minus6\p@}%
           \@setfontsize@parms{48\p@ plus30\p@ minus6\p@}{27}{11}}
\def\LARGE{\@setfontsize\LARGE\ithirtyfourpt{48\p@ plus10\p@ minus6\p@}%
           \@setfontsize@parms{52\p@ plus30\p@ minus6\p@}{27}{11}}
\def\huge{\@setfontsize\huge\ifortyonept{56\p@ plus10\p@ minus6\p@}%
           \@setfontsize@parms{60\p@ plus30\p@ minus6\p@}{27}{11}}
\let\Huge\huge
\renewcommand\baselinestretch{}
\setlength\parindent{\z@}
\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301
\setlength\smallskipamount{5\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\medskipamount {10\p@ \@plus 4\p@ \@minus 4\p@}
\setlength\bigskipamount {20\p@ \@plus 8\p@ \@minus 8\p@}
\setlength\jot{10pt}
\setlength\headheight{14\p@}
\setlength\headsep   {8\p@}
\setlength\topskip   {20\p@}
\setlength\footskip  {25\p@}
\if@compatibility
  \setlength\maxdepth{4\p@}
\else
  \setlength\maxdepth{.5\topskip}
\fi
\setlength\@maxdepth\maxdepth
\if@compatibility
  \setlength\textwidth{460\p@}
\else
  \setlength\textwidth{\paperwidth}
  \addtolength\textwidth{-2in}
\fi
\@settopoint\textwidth
\columnwidth\textwidth
\columnsep 10pt
\columnseprule\z@
\if@compatibility
  \setlength\textheight{600\p@}
\else
  \setlength\textheight{\paperheight}
  \addtolength\textheight{-2in}
\fi
\addtolength\textheight{\topskip}
\if@compatibility
  \setlength\oddsidemargin  {17\p@}
  \setlength\evensidemargin {17\p@}
  \setlength\marginparwidth {20\p@}
\else
  \setlength\oddsidemargin  {\z@}
  \setlength\evensidemargin {\z@}
  \setlength\marginparwidth {.8in}
\fi
\setlength\marginparsep {5\p@}
\setlength\marginparpush{5\p@}
\if@compatibility
  \setlength\topmargin{-10pt}
\else
  \setlength\topmargin{-\headheight}
  \addtolength\topmargin{-\headsep}
  \addtolength\topmargin{-\topskip}
\fi
\setlength\footnotesep{20\p@}
\setlength{\skip\footins}{10\p@ \@plus 2\p@ \@minus 4\p@}

\def\ps@empty{%
  \def\ps@slide{\def\@oddhead{}\def\@oddfoot{}}
  \def\ps@note{\def\@oddhead{}\def\@oddfoot{}}}
\def\ps@plain{%
  \def\ps@slide{\def\@oddhead{}%
    \def\@oddfoot{\hfil\tiny\slidemarker\theslide}}
  \def\ps@note{\def\@oddfoot{\hfil\tiny\thenote}%
    \def\@oddhead{}}}
\def\ps@headings{%
  \def\ps@slide{%
    \def\@oddhead{\tiny\@title\hfil\slidemarker\theslide%
    \def\@oddfoot{\tiny\@author\hfil\@date}}}
  \def\ps@note{\def\@oddfoot{\hfil\tiny\thenote}%
    \def\@oddhead{}}}
\def\ps@custom{%
  \def\ps@slide{%
    \def\@oddhead{\tiny\makehead}%
    \def\@oddfoot{\tiny\makefoot}}
  \def\ps@note{\def\@oddfoot{\hfil\tiny\thenote}%
    \def\@oddhead{}}}
\let\makehead\@empty \let\makefoot\@empty
\ps@plain
\let\@oddhead\@empty\let\@oddfoot\@empty
\let\@evenhead\@empty\let\@evenfoot\@empty
\SetSymbolFont{operators}{normal}
                 {OT1}{lcmss}{m}{n}
\SetSymbolFont{letters}{normal}
                 {OML}{lcmm}{m}{it}
\SetSymbolFont{symbols}{normal}
                 {OMS}{lcmsy}{m}{n}
\SetSymbolFont{largesymbols}{normal}
                 {OMX}{lcmex}{m}{n}

\newenvironment{titlepage}{\newpage
                           \thispagestyle{empty}%
                           \setcounter{page}{\z@}}
                          {\newpage}
\newenvironment{titleslide}{\slide
                            \thispagestyle{empty}%
                            \setcounter{slide}{\z@}}
                           {\endslide}
\if@titleslide
  \newcommand\maketitle{%
    \begin{titleslide}
      \@maketitle
    \end{titleslide}}
\else\if@titlepage
  \newcommand\maketitle{%
    \begin{titlepage}
      \@maketitle
    \end{titlepage}}
\else
  \newcommand\maketitle{%
    {\@maketitle\par}%
    \bigskip}
\fi\fi

\newcommand\@maketitle{%
  \centering 
  \textbf{\huge\@title}\par
  \Large\@author\par
  \textit{\@date}}

\setlength\leftmargini   {35\p@}
\setlength\leftmarginii  {30\p@}
\setlength\leftmarginiii {25\p@}
\setlength\leftmarginiv  {20\p@}
\setlength\leftmarginv   {15\p@}
\setlength\leftmarginvi  {10\p@}
\def\@listi{\leftmargin\leftmargini
             \parsep\parskip
             \divide\parsep by\thr@@
             \topsep-\parsep
             \partopsep\parsep
             \itemsep\parsep}
\def\@listii{\leftmargin\leftmarginii
             \labelwidth\leftmarginii
             \advance\labelwidth-\labelsep
             \parsep\parskip
             \divide\parsep by\thr@@
             \topsep-\parsep
             \partopsep\parsep
             \itemsep\parsep}
\def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep}
\def\@listiv{\leftmargin\leftmarginiv
             \labelwidth\leftmarginiv
             \advance\labelwidth-\labelsep}
\def\@listv{\leftmargin\leftmarginv
            \labelwidth\leftmarginv
            \advance\labelwidth-\labelsep}
\def\@listvi{\leftmargin\leftmarginvi
             \labelwidth\leftmarginvi
             \advance\labelwidth-\labelsep}
\leftmargin\leftmargini
\labelwidth\leftmargini \advance\labelwidth-\labelsep
\newenvironment{verse}{\let\\=\@centercr
                       \list{}{\itemsep       \z@
                               \itemindent    -15\p@
                               \listparindent \itemindent
                               \rightmargin   \leftmargin
                               \advance\leftmargin 15\p@}%
                       \item[]}
                      {\endlist}
\newenvironment{quotation}{\list{}{\listparindent 20\p@
                                   \itemindent\listparindent
                                   \rightmargin\leftmargin}%
                           \item[]}
                          {\endlist}
\newenvironment{quote}{\list{}{\rightmargin\leftmargin}\item[]}
                      {\endlist}
\newenvironment{description}{\list{}{\labelwidth\z@
                                     \itemindent-\leftmargin
                                     \let\makelabel\descriptionlabel}}
                            {\endlist}
\newcommand*{\descriptionlabel}[1]{\hspace\labelsep
                                \normalfont\bfseries #1}

\renewcommand\theenumi{\@arabic\c@enumi}
\renewcommand\theenumii{\@alph\c@enumii}
\renewcommand\theenumiii{\@roman\c@enumiii}
\renewcommand\theenumiv{\@Alph\c@enumiv}
\newcommand\labelenumi{\theenumi.}
\newcommand\labelenumii{(\theenumii)}
\newcommand\labelenumiii{\theenumiii.}
\newcommand\labelenumiv{\theenumiv.}
\renewcommand\p@enumii{\theenumi}
\renewcommand\p@enumiii{\theenumi(\theenumii)}
\renewcommand\p@enumiv{\p@enumiii\theenumiii}
\newcommand\labelitemi{$\m@th\bullet$}
\newcommand\labelitemii{\normalfont\bfseries \textendash}
\newcommand\labelitemiii{$\m@th\ast$}
\newcommand\labelitemiv{$\m@th\cdot$}
\setlength\arraycolsep{8\p@}
\setlength\tabcolsep{10\p@}
\setlength\arrayrulewidth{.6\p@}
\setlength\doublerulesep{3\p@}
\labelsep 10pt
\setlength\tabbingsep{\labelsep}
\skip\@mpfootins = \skip\footins
\setlength\fboxsep{5\p@}
\setlength\fboxrule{.6\p@}
\def\theequation{\@arabic\c@equation}
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\relax}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\relax}
\DeclareRobustCommand*{\cal}{\@fontswitch{\relax}{\mathcal}}
\DeclareRobustCommand*{\mit}{\@fontswitch{\relax}{\mathnormal}}
\renewcommand\footnoterule{}
\def\thefootnote{\fnsymbol{footnote}}
\@addtoreset{footnote}{slide}
\@addtoreset{footnote}{note}
\long\def\@makefntext#1{%
  \noindent
  \hangindent 10\p@
  \hb@xt@10\p@{\hss\@makefnmark}#1}

\newcommand\today{\ifcase\month\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or December\fi
  \space\number\day, \number\year}
\onecolumn

\newtoks\everyslide
\newbox\slidebox

\newcounter{part}
\renewcommand\thepart{\Roman{part}}
\newcommand\partname{Part}

\if@slides
  \countdef\c@slide=0 \c@slide=0
  \let\cl@slide\@empty
  \let\p@slide\@empty
  \def\theslide{\@arabic\c@slide}
  \@addtoreset{slide}{@ckpt}
  \@addtoreset{slide}{part}
  \countdef\c@page=1 \c@page=0
  \def\thepage{\@arabic\c@slide}
  \@addtoreset{page}{slide}
\else
  \newcounter{slide}[part]
  \pagenumbering{arabic}
\fi

\newcommand{\slidemarker}{\#}

\newcommand{\ovalframesize}{\thicklines}
\newlength\ovalcornersize\setlength\ovalcornersize{30pt}
\newlength\slideboxrule  \setlength\slideboxrule  {5pt}
\newlength\slideboxsep   \setlength\slideboxsep   {30pt}
\newlength\slidetitlesep \setlength\slidetitlesep {10\p@\@plus5\p@\@minus5\p@}

\newcommand{\slidetitlefont}{\Large\bfseries}
\newcommand*{\slidetitle}[2][\slidetitlefont]{{\centering#1#2\par}}

\newcommand\part{%
  \begin{slide} \thispagestyle{empty}%
  \secdef\@part\@spart}
\def\@part[#1]#2{%
  \ifnum \c@secnumdepth >-2\relax
    \refstepcounter{part}%
    \addcontentsline{toc}{part}{\thepart\hspace{1em}#1}%
  \else
    \addcontentsline{toc}{part}{#1}%
  \fi
  {\centering \normalfont
   \ifnum \c@secnumdepth >-2\relax
     \huge \bfseries \partname~\thepart \par
     \vskip 20\p@
   \fi
   \Huge \bfseries #2\par}%
  \@endpart}
\def\@spart#1{%
  {\centering \normalfont
   \Huge \bfseries #1\par}%
  \@endpart}
\def\@endpart{\end{slide}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% usage:
%%  \begin{slide}[<title>][<width>][<alignment>]
%%   <slide contents>
%%  \end{slide}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newenvironment{slide}{\begin{@slide}}{\end{@slide}}

\def\@slide{%
  \@ifnextchar[%]
    \@islide
    {\@islide[]}}
\def\@islide[#1]{%
  \@ifnextchar[%]
    {\@iislide{#1}}
    {\@iislide{#1}[\textwidth]}}
\def\@iislide#1[#2]{%
  \@ifnextchar[%]
    {\@iiislide{#1}{#2}}
    {\@iiislide{#1}{#2}[\slidealignment]}}
\def\@iiislide#1#2[#3]{%
  \newpage
  \stepcounter{slide}%
  \thispagestyle{slide}%
  %% count slide interior dimensions
  \setlength\@tempdima{#2}%
  \@tempdimb=\textheight
  \ifnum\framevariant>0 %% any frame
      \advance\@tempdimb-\tw@\slideboxsep
      \ifnum\framevariant<4 %% rules, rect & shadow
          \advance\@tempdimb-\tw@\slideboxrule \fi
      \ifnum\framevariant>1 %% any frame but rules
          \advance\@tempdima-\tw@\slideboxsep
          \ifnum\framevariant<4 %% rect & shadow
              \advance\@tempdima-\tw@\slideboxrule \fi
          \if\framevariant 3 %% shadow
              \advance\@tempdima-\shadowsize
              \advance\@tempdimb-\shadowsize \fi
          \if\framevariant 4 %% double
              \advance\@tempdima-7.5\slideboxrule
              \advance\@tempdima-1pt
              \advance\@tempdimb-7.5\slideboxrule
              \advance\@tempdimb-1pt \fi
          \if\framevariant 5 %% oval
              \ovalframesize %% should be in a block
              \advance\@tempdima-\tw@\@wholewidth
              \advance\@tempdimb-\tw@\@wholewidth \fi\fi\fi
  %% slide alignment
  \if#3s\def\@align@slide{\unvbox\slidebox}
  \else\if#3t\def\@align@slide{\unvbox\slidebox\vfil}
  \else\if#3c\def\@align@slide{\vfil\unvbox\slidebox\vfil}
  \else\if#3b\def\@align@slide{\vfil\unvbox\slidebox}
  \else\ClassError{slideshow}{Incorrect slide alignment specification: #1}
    {Slide alignment may be specified using one of the letters:\MessageBreak
      s(tretch), t(op), c(enter), b(ottom)}
  \fi\fi\fi\fi
  \the\everyslide
  \begin{saveminipage}[\@tempdima]{\slidebox}%
  \normalfont \normalsize
  \ifx\@empty#1\@empty\else
      \slidetitle{#1}%
      \if@belowheadfil
        \vfil
      \else
        \vspace\slidetitlesep\fi\fi}

\def\end@slide{%
  \ifhmode\unskip\par\fi
  \end{saveminipage}%
  \setbox\slidebox\vbox to\@tempdimb{\@align@slide}%
  \begin{center}
  \fboxsep\slideboxsep
  \ifcase\framevariant %% noframe
      \box\slidebox
  \or %% rules
      \vbox{%
        \hrule\@height\slideboxrule
        \vskip\fboxsep
        \box\slidebox
        \vskip\fboxsep
        \hrule\@height\slideboxrule}
  \or %% rect
      \frbox[\fboxrule\slideboxrule]{\box\slidebox}
  \or %% shadow
      \shbox[\fboxrule\slideboxrule]{\box\slidebox}
  \or %% double
      \dblbox[\fboxrule\slideboxrule]{\box\slidebox}
  \or %% oval
      \obox[\ovalframesize \cornersize*{\ovalcornersize}]{\box\slidebox}\fi
  \end{center}
  \newpage
}

%% typesetting parameters following FoilTeX package
\tolerance=1000
\hfuzz=2\p@
\vfuzz=2\p@
\hbadness=2000

%% EOF
